=== modified file 'bzrlib/conflicts.py'
--- bzrlib/conflicts.py	2007-03-03 17:17:53 +0000
+++ bzrlib/conflicts.py	2007-03-06 15:36:36 +0000
@@ -283,12 +283,15 @@
 
     def __init__(self, path, file_id=None):
         self.path = path
-        self.file_id = file_id
+        # warn turned off, because the factory blindly transfers the Stanza
+        # values to __init__ and Stanza is purely a Unicode api.
+        self.file_id = osutils.safe_file_id(file_id, warn=False)
 
     def as_stanza(self):
         s = rio.Stanza(type=self.typestring, path=self.path)
         if self.file_id is not None:
-            s.add('file_id', self.file_id)
+            # Stanza requires Unicode apis
+            s.add('file_id', self.file_id.decode('utf8'))
         return s
 
     def _cmp_list(self):
@@ -402,7 +405,10 @@
                  conflict_file_id=None):
         HandledConflict.__init__(self, action, path, file_id)
         self.conflict_path = conflict_path 
-        self.conflict_file_id = conflict_file_id
+        # warn turned off, because the factory blindly transfers the Stanza
+        # values to __init__.
+        self.conflict_file_id = osutils.safe_file_id(conflict_file_id,
+                                                     warn=False)
         
     def _cmp_list(self):
         return HandledConflict._cmp_list(self) + [self.conflict_path, 
@@ -412,7 +418,7 @@
         s = HandledConflict.as_stanza(self)
         s.add('conflict_path', self.conflict_path)
         if self.conflict_file_id is not None:
-            s.add('conflict_file_id', self.conflict_file_id)
+            s.add('conflict_file_id', self.conflict_file_id.decode('utf8'))
             
         return s
 

=== modified file 'bzrlib/tests/test_conflicts.py'
--- bzrlib/tests/test_conflicts.py	2007-03-03 01:09:18 +0000
+++ bzrlib/tests/test_conflicts.py	2007-03-06 15:36:36 +0000
@@ -32,16 +32,21 @@
 
 # The order of 'path' here is important - do not let it
 # be a sorted list.
+# u'\xe5' == a with circle
+# '\xc3\xae' == u'\xee' == i with hat
+# So these are u'pathg' and 'idg' only with a circle and a hat. (shappo?)
 example_conflicts = ConflictList([ 
-    MissingParent('Not deleting', 'pathg', 'idg'),
-    ContentsConflict('patha', 'ida'), 
-    TextConflict('patha'),
-    PathConflict('pathb', 'pathc', 'idb'),
-    DuplicateID('Unversioned existing file', 'pathc', 'pathc2', 'idc', 'idc'),
-    DuplicateEntry('Moved existing file to',  'pathdd.moved', 'pathd', 'idd', 
-                   None),
-    ParentLoop('Cancelled move', 'pathe', 'path2e', None, 'id2e'),
-    UnversionedParent('Versioned directory', 'pathf', 'idf'),
+    MissingParent('Not deleting', u'p\xe5thg', '\xc3\xaedg'),
+    ContentsConflict(u'p\xe5tha', None, '\xc3\xaeda'), 
+    TextConflict(u'p\xe5tha'),
+    PathConflict(u'p\xe5thb', u'p\xe5thc', '\xc3\xaedb'),
+    DuplicateID('Unversioned existing file', u'p\xe5thc', u'p\xe5thc2',
+                '\xc3\xaedc', '\xc3\xaedc'),
+    DuplicateEntry('Moved existing file to',  u'p\xe5thdd.moved', u'p\xe5thd',
+                   '\xc3\xaedd', None),
+    ParentLoop('Cancelled move', u'p\xe5the', u'p\xe5th2e',
+               None, '\xc3\xaed2e'),
+    UnversionedParent('Versioned directory', u'p\xe5thf', '\xc3\xaedf'),
 ])
 
 
@@ -89,18 +94,29 @@
         # write and read our example stanza.
         stanza_iter = example_conflicts.to_stanzas()
         processed = ConflictList.from_stanzas(stanza_iter)
-        for o,p in zip(processed, example_conflicts):
+        for o, p in zip(processed, example_conflicts):
             self.assertEqual(o, p)
 
+            self.assertIsInstance(o.path, unicode)
+
+            if o.file_id is not None:
+                self.assertIsInstance(o.file_id, str)
+
+            conflict_file_path = getattr(o, 'conflict_file_path', None)
+            if conflict_file_path is not None:
+                self.assertIsInstance(conflict_file_path, unicode)
+
+            conflict_file_id = getattr(o, 'conflict_file_id', None)
+            if conflict_file_id is not None:
+                self.assertIsInstance(conflict_file_id, str)
+
     def test_stanzification(self):
         for stanza in example_conflicts.to_stanzas():
-            try:
-                self.assertStartsWith(stanza['file_id'], 'id')
-            except KeyError:
-                pass
-            self.assertStartsWith(stanza['path'], 'path')
-            try:
-                self.assertStartsWith(stanza['conflict_file_id'], 'id')
-                self.assertStartsWith(stanza['conflict_file_path'], 'path')
-            except KeyError:
-                pass
+            if 'file_id' in stanza:
+                # In Stanza form, the file_id has to be unicode.
+                self.assertStartsWith(stanza['file_id'], u'\xeed')
+            self.assertStartsWith(stanza['path'], u'p\xe5th')
+            if 'conflict_file_path' in stanza:
+                self.assertStartsWith(stanza['conflict_file_path'], u'p\xe5th')
+            if 'conflict_file_id' in stanza:
+                self.assertStartsWith(stanza['conflict_file_id'], u'\xeed')

